@@ -293,8 +293,8 @@ def run_tasks(
                 logging.info(f"Sending {len(entries)} events to eventbridge")
                 with betterboto_client.CrossAccountClientContextManager(
                     "events",
-                    f"arn:aws:iam::{current_account_id}:role/servicecatalog-puppet/PuppetRole",
-                    f"{current_account_id}-PuppetRole",
+                    config.get_puppet_role_arn(current_account_id),
+                    f"{current_account_id}-{config.get_puppet_role_name()}",
                 ) as events:
                     for i in range(
                         0, len(entries), constants.EVENTBRIDGE_MAX_EVENTS_PER_CALL
